@@ -97,7 +97,7 @@ def create_neighborhood_matrix(all_data, dist_mat_dir, included_fovs=None, distl
 
     # Remove cells that have no neighbors within the distlim
     total_cell_count = cell_neighbor_counts.shape[0]
-    keep_cells = cell_neighbor_counts.drop([fov_col, cell_label_col], axis=1).sum(axis=1) != 0
+    keep_cells = cell_neighbor_counts.drop(included_columns, axis=1).sum(axis=1) != 0
     cell_neighbor_counts = cell_neighbor_counts.loc[keep_cells].reset_index(drop=True)
     cell_neighbor_freqs = cell_neighbor_freqs.loc[keep_cells].reset_index(drop=True)
     # issue warning if more than 5% of cells are dropped
