@@ -86,7 +86,8 @@ def plot_neighborhood_cluster_result(img_xr, fovs, k, save_dir=None, cmap_name='
 
 # TODO: possibly need to merge this with plot_neighborhood_cluster_result
 def plot_pixel_cell_cluster_overlay(img_xr, fovs, cluster_id_to_name_path, metacluster_colors,
-                                    save_dir=None, fov_col='fovs', figsize=(10, 10)):
+                                    cluster_type='pixel', save_dir=None, fov_col='fovs',
+                                    figsize=(10, 10)):
     """Overlays the pixel and cell clusters on an image
 
     Args:
@@ -99,6 +100,8 @@ def plot_pixel_cell_cluster_overlay(img_xr, fovs, cluster_id_to_name_path, metac
             this is output by the remapping visualization found in `metacluster_remap_gui`
         metacluster_colors (dict):
             maps each metacluster id to a color
+        cluster_type (str):
+            the type of clustering being done
         save_dir (str):
             If provided, the image will be saved to this location.
         fov_col (str):
@@ -107,6 +110,12 @@ def plot_pixel_cell_cluster_overlay(img_xr, fovs, cluster_id_to_name_path, metac
             Size of the image that will be displayed.
     """
 
+    # verify the type of clustering provided is valid
+    misc_utils.verify_in_list(
+        provided_cluster_type=[cluster_type],
+        valid_cluster_types=['pixel', 'cell']
+    )
+
     # verify the fovs are valid
     misc_utils.verify_in_list(fov_names=fovs, unique_fovs=img_xr.fovs.values)
 
@@ -121,26 +130,31 @@ def plot_pixel_cell_cluster_overlay(img_xr, fovs, cluster_id_to_name_path, metac
     # NOTE: check for 'cluster' ensures this file was generated by the interactive visualization
     misc_utils.verify_same_elements(
         cluster_mapping_cols=cluster_id_to_name.columns.values,
-        required_cols=['cluster', 'metacluster', 'mc_name']
+        required_cols=[
+            f'{cluster_type}_som_cluster',
+            f'{cluster_type}_meta_cluster',
+            f'{cluster_type}_meta_cluster_rename']
     )
 
     # subset on just metacluster and mc_name
-    metacluster_id_to_name = cluster_id_to_name[['metacluster', 'mc_name']].copy()
+    metacluster_id_to_name = cluster_id_to_name[
+        [f'{cluster_type}_meta_cluster', f'{cluster_type}_meta_cluster_rename']
+    ].copy()
 
     # take only the unique pairs
     metacluster_id_to_name = metacluster_id_to_name.drop_duplicates()
 
     # sort by metacluster id ascending, this will help when making the colormap
-    metacluster_id_to_name = metacluster_id_to_name.sort_values(by='metacluster')
+    metacluster_id_to_name = metacluster_id_to_name.sort_values(by=f'{cluster_type}_meta_cluster')
 
     # assert the metacluster index in colors matches with the ids in metacluster_id_to_name
     misc_utils.verify_same_elements(
         metacluster_colors_ids=list(metacluster_colors.keys()),
-        metacluster_mapping_ids=metacluster_id_to_name['metacluster'].values
+        metacluster_mapping_ids=metacluster_id_to_name[f'{cluster_type}_meta_cluster'].values
     )
 
     # use metacluster_colors to add the colors to metacluster_id_to_name
-    metacluster_id_to_name['color'] = metacluster_id_to_name['metacluster'].map(
+    metacluster_id_to_name['color'] = metacluster_id_to_name[f'{cluster_type}_meta_cluster'].map(
         metacluster_colors
     )
 
@@ -152,7 +166,7 @@ def plot_pixel_cell_cluster_overlay(img_xr, fovs, cluster_id_to_name_path, metac
     # is indexed correctly when plotted
     metacluster_to_index = {}
     for index, row in metacluster_id_to_name.reset_index(drop=True).iterrows():
-        metacluster_to_index[row['metacluster']] = index + 1
+        metacluster_to_index[row[f'{cluster_type}_meta_cluster']] = index + 1
 
     # generate the colormap
     cmap = colors.ListedColormap(mc_colors)
@@ -167,7 +181,7 @@ def plot_pixel_cell_cluster_overlay(img_xr, fovs, cluster_id_to_name_path, metac
 
         # assign any metacluster id not in metacluster_id_to_name to 0 (not including 0 itself)
         # done as a precaution, should not usually happen
-        acceptable_cluster_ids = [0] + list(metacluster_id_to_name['metacluster'])
+        acceptable_cluster_ids = [0] + list(metacluster_id_to_name[f'{cluster_type}_meta_cluster'])
         fov_img[~np.isin(fov_img, acceptable_cluster_ids)] = 0
 
         # explicitly relabel each value in fov_img with its index in mc_colors
@@ -203,7 +217,9 @@ def plot_pixel_cell_cluster_overlay(img_xr, fovs, cluster_id_to_name_path, metac
             cax=cax,
             orientation='vertical'
         )
-        cbar.ax.set_yticklabels(['Empty'] + list(metacluster_id_to_name['mc_name'].values))
+        cbar.ax.set_yticklabels(['Empty'] + list(
+            metacluster_id_to_name[f'{cluster_type}_meta_cluster_rename'].values)
+        )
 
         # explicitly turn off intermediate minor ticks
         for mt in cbar.ax.yaxis.get_minor_ticks():
@@ -396,6 +412,7 @@ def create_mantis_dir(fovs: List[str], mantis_project_path: Union[str, pathlib.P
                       mask_output_dir: Union[str, pathlib.Path],
                       mapping: Union[str, pathlib.Path, pd.DataFrame],
                       seg_dir: Union[str, pathlib.Path],
+                      cluster_type='pixel',
                       mask_suffix: str = "_mask",
                       seg_suffix_name: str = "_whole_cell.tiff",
                       img_sub_folder: str = ""):
@@ -437,6 +454,8 @@ def create_mantis_dir(fovs: List[str], mantis_project_path: Union[str, pathlib.P
             The location of the mapping file, or the mapping Pandas DataFrame itself.
         seg_dir (Union[str, pathlib.Path]):
             The location of the segmentation directory for the fovs.
+        cluster_type (str):
+            the type of clustering being done
         mask_suffix (str, optional):
             The suffix used to find the mask tiffs. Defaults to "_mask".
         seg_suffix_name (str, optional):
@@ -447,6 +466,12 @@ def create_mantis_dir(fovs: List[str], mantis_project_path: Union[str, pathlib.P
             Defaults to "normalized".
     """
 
+    # verify the type of clustering provided is valid
+    misc_utils.verify_in_list(
+        provided_cluster_type=[cluster_type],
+        valid_cluster_types=['pixel', 'cell']
+    )
+
     if not os.path.exists(mantis_project_path):
         os.makedirs(mantis_project_path)
 
@@ -459,13 +484,19 @@ def create_mantis_dir(fovs: List[str], mantis_project_path: Union[str, pathlib.P
         ValueError("Mapping must either be a path to an already saved mapping csv, \
                    or a DataFrame that is already loaded in.")
 
-    map_df = map_df.loc[:, ['metacluster', 'mc_name']]
+    map_df = map_df.loc[:, [f'{cluster_type}_meta_cluster', f'{cluster_type}_meta_cluster_rename']]
     # remove duplicates from df
     map_df = map_df.drop_duplicates()
-    map_df = map_df.sort_values(by=['metacluster'])
+    map_df = map_df.sort_values(by=[f'{cluster_type}_meta_cluster'])
 
     # rename for mantis names
-    map_df = map_df.rename({'metacluster': 'region_id', 'mc_name': 'region_name'}, axis=1)
+    map_df = map_df.rename(
+        {
+            f'{cluster_type}_meta_cluster': 'region_id',
+            f'{cluster_type}_meta_cluster_rename': 'region_name'
+        },
+        axis=1
+    )
 
     # get names of fovs with masks
     mask_names_loaded = (io_utils.list_files(mask_output_dir, mask_suffix))
